# ikigai

[![PyPI - Version](https://img.shields.io/pypi/v/ikigai.svg)](https://pypi.org/project/ikigai)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ikigai.svg)](https://pypi.org/project/ikigai)
[![Python Tests](https://github.com/ikigailabs-io/ikigai/actions/workflows/python-package.yml/badge.svg?branch=main)](https://github.com/ikigailabs-io/ikigai/actions/workflows/python-package.yml)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install ikigai
```

## License

`ikigai` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
